Module afp

Module afp 

Structs

FPAccessRights
AFP Directory Access Rights bitmap. This represents the access privileges for a single category (owner, group, or everyone). The full Access Rights parameter is a 4-byte value consisting of:
FPAddComment
FPAddIcon
FPByteRangeLock
FPByteRangeLockFlags
FPCloseFork
FPCopyFile
FPCopyFile: server-side copy of a file’s data and resource forks into a destination directory.
FPCreateDir
FPCreateFile
FPDelete
FPDirectoryBitmap
FPEnumerate
FPFileAttributes
FPFileBitmap
FPFlush
FPGetComment
FPGetFileDirParms
FPGetForkParms
FPGetIcon
FPGetIconInfo
FPGetSrvrInfo
FPGetSrvrParms
FPGetVolParms
FPLogin
FPLogin command - authentication request from client to server
FPMoveAndRename
FPMoveAndRename: atomically moves and/or renames a file or directory.
FPOpenDT
FPOpenFork
FPRead
FPRemoveComment
FPRename
FPRename: renames a file or directory within its current parent directory.
FPSetDirParms
FPSetFileDirParms
FPSetForkParms
Indicates a request from a client to either increase or decrease the size of a fork on disk. If neither data fork length or resource fork length are set, this command is a no-op but a success code should still be returned to the client.
FPVolume
FPVolumeBitmap
Bitmap of requested volume information. One or more of these can be set in a request by FPGetVolParms or during FPOpenVol. The response should be packed in the same order as the bits are defined below. E.g. If ATTRIBUTES and CREATION_DATE are set, the first 2 bytes of the payload will be the attributes flag, and the next 4 bytes are the creation date.
FPWrite
MacString
A utility type for handling Macintosh Pascal strings (1-byte length prefix followed by MacRoman encoded data).

Enums

AfpError
AFP Error Codes. For AppleTalk implementations these result codes are passed via the ASP CmdResult field (i.e the 4 user bytes of an ATP packet)
AfpUam
AfpVersion
CreateFlag
FPLoginAuth
Authentication payload for FPLogin, varies by UAM
FileType
ForkType
PathType
VolumeSignature

Constants

AFP_CMD_ADD_APPL
AFP_CMD_ADD_COMMENT
AFP_CMD_ADD_ICON
AFP_CMD_BYTE_RANGE_LOCK
AFP Command Codes
AFP_CMD_CLOSE_DT
AFP_CMD_CLOSE_FORK
AFP_CMD_CLOSE_VOL
AFP_CMD_COPY_FILE
AFP_CMD_CREATE_DIR
AFP_CMD_CREATE_FILE
AFP_CMD_DELETE
AFP_CMD_ENUMERATE
AFP_CMD_FLUSH
AFP_CMD_GET_COMMENT
AFP_CMD_GET_FILE_DIR_PARMS
AFP_CMD_GET_FORK_PARMS
AFP_CMD_GET_ICON
AFP_CMD_GET_SRVR_MSG
AFP_CMD_GET_SRVR_PARMS
AFP_CMD_GET_VOL_PARMS
AFP_CMD_GTICNINFO
AFP_CMD_LOGIN
AFP_CMD_LOGOUT
AFP_CMD_MOVE_AND_RENAME
AFP_CMD_OPEN_DT
AFP_CMD_OPEN_FORK
AFP_CMD_OPEN_VOL
AFP_CMD_READ
AFP_CMD_REMOVE_COMMENT
AFP_CMD_RENAME
AFP_CMD_SET_DIR_PARMS
AFP_CMD_SET_FILE_DIR_PARMS
AFP_CMD_SET_FORK_PARMS
AFP_CMD_WRITE

Functions

afp_rights_to_mode
mode_to_afp_rights