AfpError

Enum AfpError 

#[repr(i16)]
pub enum AfpError {
Show 17 variants InvalidSize = -1, EoFErr = -39, BadVersNum = -1_072, BadUam = -1_073, AccessDenied = -5_000, DirNotEmpty = -5_007, BitmapErr = -5_006, FileBusy = -5_010, ItemNotFound = -5_012, LockErr = -5_013, ObjectExists = -5_017, ObjectNotFound = -5_018, ParamError = -5_019, RangeNotLocked = -5_020, RangeOverlap = -5_021, ObjectTypeErr = -5_025, MiscErr = -10_000,
}
AFP Error Codes. For AppleTalk implementations these result codes are passed via the ASP CmdResult field (i.e the 4 user bytes of an ATP packet)

Variants



InvalidSize = -1

Packet could not be parsed as it was of insufficient size



EoFErr = -39

End of File reached



BadVersNum = -1_072

Unknown or unsupported AFP version



BadUam = -1_073

Unknown or unsupported UAM



AccessDenied = -5_000

User does not have the correct access rights



DirNotEmpty = -5_007

A request to operate on a directory that is not empty



BitmapErr = -5_006

Bitmap is invalid



FileBusy = -5_010

A request to operate on a file that is currently in use



ItemNotFound = -5_012

Item not found



LockErr = -5_013

General lock error



ObjectExists = -5_017

Object (file or directory) already exists



ObjectNotFound = -5_018

Object (file or directory) not found



ParamError = -5_019

AFP command block size is zero or invalid



RangeNotLocked = -5_020

Attempt to unlock a byte range that is not locked



RangeOverlap = -5_021

Attempt to lock a byte range that overlaps with an existing lock



ObjectTypeErr = -5_025

Object is the wrong type (e.g. file vs directory)



MiscErr = -10_000

Miscellaneous error