pub struct FPDirectoryBitmap(/* private fields */);Implementations
Sourceimpl FPDirectoryBitmap
impl FPDirectoryBitmap
Sourcepub const ATTRIBUTES: Self
pub const ATTRIBUTES: Self
Request for the attributes of this directory. TODO: Implement attributes bit flag response
Sourcepub const PARENT_DIR_ID: Self
pub const PARENT_DIR_ID: Self
Request for the parent directory ID of this directory. Response: 32-bit directory ID
Sourcepub const CREATE_DATE: Self
pub const CREATE_DATE: Self
Request for the creation date of this directory. Response: 32-bit Macintosh time
Sourcepub const MODIFICATION_DATE: Self
pub const MODIFICATION_DATE: Self
Request for the last modification date of ths directory. Response: 32-bit Macintosh time
Sourcepub const BACKUP_DATE: Self
pub const BACKUP_DATE: Self
Request for the last backup date of this directory. Response: 32-bit Macintosh time
Sourcepub const FINDER_INFO: Self
pub const FINDER_INFO: Self
Request for the Finder information of this directory. Response: 32-byte Finder information
Sourcepub const LONG_NAME: Self
pub const LONG_NAME: Self
Request for the long name of this directory. Response: Offset returned in order to a pascal string with the long name
Sourcepub const SHORT_NAME: Self
pub const SHORT_NAME: Self
Request for the short name of this directory. Response: Offset returned in order to a pascal string with the short name
Sourcepub const DIR_ID: Self
pub const DIR_ID: Self
Request for the directory ID of this directory. Response: 32-bit directory ID
Sourcepub const OFFSPRING_COUNT: Self
pub const OFFSPRING_COUNT: Self
Request for the number of offspring of this directory. Response: 16-bit number of offspring
Sourcepub const ACCESS_RIGHTS: Self
pub const ACCESS_RIGHTS: Self
Request for the access rights of this directory. Response: 4-byte value in the order of owner, group, and world followed by a User Access Rights summary byte
Sourcepub const PRODOS_INFO: Self
pub const PRODOS_INFO: Self
TODO: What is this?
Sourceimpl FPDirectoryBitmap
impl FPDirectoryBitmap
Sourcepub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u16) -> Option<Self>
pub const fn from_bits(bits: u16) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u16) -> Self
pub const fn from_bits_truncate(bits: u16) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u16) -> Self
pub const fn from_bits_retain(bits: u16) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl FPDirectoryBitmap
impl FPDirectoryBitmap
Sourcepub const fn iter(&self) -> Iter<FPDirectoryBitmap>
pub const fn iter(&self) -> Iter<FPDirectoryBitmap>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<FPDirectoryBitmap>
pub const fn iter_names(&self) -> IterNames<FPDirectoryBitmap>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl FPDirectoryBitmap
impl FPDirectoryBitmap
Sourcepub fn long_name_offset(&self) -> usize
pub fn long_name_offset(&self) -> usize
Returns the expected offset of the long_name value based on the set bitmap values.
pub fn response_len(&self, name_len: usize) -> usize