pub struct FPRead {
pub fork_id: u16,
pub offset: u32,
pub req_count: u32,
pub newline_mask: u8,
pub newline_char: u8,
}Fields
fork_id: u16The Fork ID this request is wanting to read from. Must be open already.
offset: u32The offset into the fork to start reading from.
req_count: u32The number of bytes requested to be read. Note that this can be higher than the ASP QuantumSize. The server should truncate the response to the QuantumSize.
newline_mask: u8The newline mask to use when reading the file. If set to a non-zero value it is to be AND’d with each byte read from the fork and the result compared to to Self::newline_char. If they match the read should be terminated at this point and the server should return the number of bytes read.
newline_char: u8The newline character to be searching for where to terminate the read.
Implementations