pub struct FPVolumeBitmap(/* private fields */);Expand description
Bitmap of requested volume information. One or more of these can be set in a request by FPGetVolParms or during FPOpenVol. The response should be packed in the same order as the bits are defined below. E.g. If ATTRIBUTES and CREATION_DATE are set, the first 2 bytes of the payload will be the attributes flag, and the next 4 bytes are the creation date.
Implementations
Sourceimpl FPVolumeBitmap
impl FPVolumeBitmap
Sourcepub const ATTRIBUTES: Self
pub const ATTRIBUTES: Self
Request for volume attributes. Single bit flag response of read-only, 1 is true, 0 is false.
Sourcepub const SIGNATURE: Self
pub const SIGNATURE: Self
Request for volume signature, i.e a flat without directories, fixed directory ID, or variable directory IDs.
Sourcepub const CREATION_DATE: Self
pub const CREATION_DATE: Self
Request for creation date of this volume (In 32-bit Macintosh time)
Sourcepub const MODIFICATION_DATE: Self
pub const MODIFICATION_DATE: Self
Request for last modified date of this volume (In 32-bit Macintosh time)
Sourcepub const BACKUP_DATE: Self
pub const BACKUP_DATE: Self
Request for the last time this volume was backed up (In 32-bit Macintosh time)
Sourcepub const BYTES_FREE: Self
pub const BYTES_FREE: Self
Request for the number of bytes free for this volume as a 32-bit value.
Sourcepub const BYTES_TOTAL: Self
pub const BYTES_TOTAL: Self
Request for the size of this volume in bytes as a 32-bit value.
Sourcepub const VOLUME_NAME: Self
pub const VOLUME_NAME: Self
Request for the name of this volume as a Pascal string.
Sourceimpl FPVolumeBitmap
impl FPVolumeBitmap
Sourcepub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u16) -> Option<Self>
pub const fn from_bits(bits: u16) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u16) -> Self
pub const fn from_bits_truncate(bits: u16) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u16) -> Self
pub const fn from_bits_retain(bits: u16) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl FPVolumeBitmap
impl FPVolumeBitmap
Sourcepub const fn iter(&self) -> Iter<FPVolumeBitmap>
pub const fn iter(&self) -> Iter<FPVolumeBitmap>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<FPVolumeBitmap>
pub const fn iter_names(&self) -> IterNames<FPVolumeBitmap>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.